* Replication dofile for:
*--------------------------
* Gschwend, Thomas. 2007. Institutional Incentives for Strategic Voting and Party System Change in Portugal.
* Portuguese Journal of Social Science 6(1): 15-31.

* please specify the directory on your machine where replication_Gschwend2007portugal.dta can be found



version 10
set more off

clear
log using replication_Gschwend2007portugal.log, replace

use replication_Gschwend2007portugal.dta

***********
* table 3 *
***********

* Restricted Model
reg  votes votes_1  exp0  y1976-y1999, cluster(pd)

* full model 
reg  votes votes_1 lnm exp0  lexp0 y1976-y1999, cluster(pd)


************
* Figure 1 *
************

matrix V = e(V)
matrix b=e(b)


* y = b5 + (b1)*NV + (b2)*ln(M)_1 + (b3)*EXP + (b4)*ln(M)*EXP
*sigma(delta Y/delta EXP = sqrt( var(b2) + ln(M)*ln(M)*var(b4) + 2*ln(M)*cov(b2,b4) )

*causal effect of EXP: Y(EXP=1)- Y(EXP=0):
*= b3 + b4*ln(M)
gen sterr = sqrt(el(V, 3,3) + lnm*lnm*(el(V, 4,4)) + 2*lnm*(el(V, 3,4)))
gen slope =  _b[exp0]+ _b[lexp0]*lnm
gen slopehi =  slope+1.96*sterr 
gen slopelo =  slope-1.96*sterr

#delimit ;
twoway rarea slopelo slopehi magnitude, sort bcolor(gs14) || line slope magnitude, sort||, 
  title( "Causal Effect of Expectations", span)
  subtitle(" ") legend(off)   xtitle(" " " "  "District Magnitude")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(fcolor(white))
  saving(exp, replace)

xlab(3(1)18 36(1)39 48(1)50 55 56 58, labsize(1.7) angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%",angle(0)) ytitle("");
#delimit cr
drop sterr slope*

***********
* Table 4 *
***********

gen d1987 = (year>=1987)
gen dexp07  = d1987*exp0


sort  party district year 

*gen learnlocall=log(learnlocal)

gen eexp0 =learnlocal*exp0
gen y1exp0 = year1*exp0

reg  votes votes_1 exp0  d1987 dexp07 , cluster(pd)
reg  votes votes_1 exp0  d1987 dexp07 learnlocal eexp0 year1 y1exp0, cluster(pd)


************
* Figure 2 *
************

reg  votes votes_1 exp0 learnlocal eexp0 year1 y1exp0 d1987 dexp07 , cluster(pd)
tab learnlocal if e(sample) & d1987==1 & year1==1
tab learnlocal if e(sample) & d1987==1 & year1==0
tab learnlocal if e(sample) & d1987==0 & year1==1
tab learnlocal if e(sample) & d1987==0 & year1==0

reg  votes votes_1 exp0 learnlocal eexp0 year1 y1exp0 d1987 dexp07 , cluster(pd)
matrix V = e(V)
* matrix list V
* y = b9 + (b1)*NV + (b2)*EXP0 + (b3)*LEARN + (b4)*LEARN*EXP0 + ...+ (b6)*year1*EXP0 + (b8)*d1987*EXP0

*According to Aiken/West, Multiple Regression: Testing and Interpreting Interactions. 
*Sage: Newbury Park, 1991, page 60.
*= b2 + b4*LEARN + b6*year1 + b8*d1987  
*StdErr of  (b2 + b4*X + b6*Z + b8*W)  = sqrt( var(b2) + X*X*var(b4) + W*W*var(b8)+ Z*Z*var(b6)
*                                        + 2*X*cov(b2,b4) + 2*Z*cov(b2,b6) + 2*W*cov(b2,b8) 
*                                        + 2*X*W*cov(b4,b8) + 2*X*Z*cov(b4,b6) + 2*W*Z*cov(b6,b8) )

*with d1987=1, year1=1



#delimit ;
gen sterr = sqrt( (el(V, 2,2)) +  learnlocal*learnlocal*(el(V, 4,4)) + (el(V, 6,6)) + (el(V, 8,8))
                 + 2*learnlocal*(el(V, 2,4)) + 2*(el(V, 2,6)) + 2*(el(V, 2,8))
                 + 2*learnlocal*(el(V, 4,8))+ 2*learnlocal*(el(V, 4,6))+ 2*(el(V, 6,8)) );
#delimit cr

gen slope11 =  _b[exp0]+ _b[eexp0]*learnlocal +  _b[y1exp0]+ _b[dexp07]
gen slopehi =  slope11+1.96*sterr 
gen slopelo =  slope11-1.96*sterr

*gen slopehi =  slope+sterr 
*gen slopelo =  slope-sterr


#delimit ;
twoway rarea slopelo slopehi learnlocal if learnlocal>0 & learnlocal<=7, sort bcolor(gs14) 
|| line slope11 learnlocal if learnlocal>0 & learnlocal<=7, sort||,  
  subtitle(" ") legend(off)   xtitle(" "   "No. of Elections")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(color(white)) note("N=147; Scenario: 1987 and later = 1, Contamination = 1")
  saving(learn11, replace)
xlab(1(1)10,  angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%" -0.1 "-10%",angle(0) nogrid) ytitle("");
#delimit cr

drop  sterr slopehi slopelo 


***with d1987=0, year1=1

#delimit ;
gen sterr = sqrt( (el(V, 2,2)) +  learnlocal*learnlocal*(el(V, 4,4)) + (el(V, 6,6)) 
                 + 2*learnlocal*(el(V, 2,4)) + 2*(el(V, 2,6)) 
                 + 2*learnlocal*(el(V, 4,6)) );
#delimit cr

gen slope01 =  _b[exp0]+ _b[eexp0]*learnlocal +  _b[y1exp0]
gen slopehi =  slope01+1.96*sterr 
gen slopelo =  slope01-1.96*sterr

*gen slopehi =  slope+sterr 
*gen slopelo =  slope-sterr


#delimit ;
twoway rarea slopelo slopehi learnlocal if learnlocal>0 &  learnlocal<=3, sort bcolor(gs14) 
|| line slope01 learnlocal if learnlocal>0 &  learnlocal<=3, sort||,  
  subtitle(" ") legend(off)   xtitle(" "   "No. of Elections")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(color(white)) note("N=648; Scenario: 1987 and later = 0, Contamination = 1")
  saving(learn01, replace)
xlab(1(1)10,  angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%" -0.1 "-10%",angle(0) nogrid) ytitle("");
#delimit cr

drop  sterr slopehi slopelo 




***with d1987=1, year1=0

#delimit ;
gen sterr = sqrt( (el(V, 2,2)) +  learnlocal*learnlocal*(el(V, 4,4))  + (el(V, 8,8))
                 + 2*learnlocal*(el(V, 2,4))  + 2*(el(V, 2,8))
                 + 2*learnlocal*(el(V, 4,8)) );
#delimit cr

gen slope10 =  _b[exp0]+ _b[eexp0]*learnlocal + _b[dexp07]
gen slopehi =  slope10+1.96*sterr 
gen slopelo =  slope10-1.96*sterr

*gen slopehi =  slope+sterr 
*gen slopelo =  slope-sterr


#delimit ;
twoway rarea slopelo slopehi learnlocal if learnlocal>0 &  learnlocal<=10, sort bcolor(gs14) 
|| line slope10 learnlocal if learnlocal>0 &  learnlocal<=10, sort||,  
  subtitle(" ") legend(off)   xtitle(" "   "No. of Elections")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(color(white)) note("N=267; Scenario: 1987 and later = 1, Contamination = 0")
  saving(learn10, replace)  
xlab(1(1)10,  angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%" -0.1 "-10%",angle(0) nogrid) ytitle("");
#delimit cr

drop  sterr slopehi slopelo 



***with d1987=0, year1=0

#delimit ;
gen sterr = sqrt( (el(V, 2,2)) +  learnlocal*learnlocal*(el(V, 4,4)) 
                 + 2*learnlocal*(el(V, 2,4)) );
#delimit cr

gen slope00 =  _b[exp0]+ _b[eexp0]*learnlocal 
gen slopehi =  slope00+1.96*sterr 
gen slopelo =  slope00-1.96*sterr

*gen slopehi =  slope+sterr 
*gen slopelo =  slope-sterr


#delimit ;
twoway rarea slopelo slopehi learnlocal if learnlocal>0 &  learnlocal<=5, sort bcolor(gs14) 
|| line slope00 learnlocal if learnlocal>0 &  learnlocal<=5, sort||,  
  subtitle(" ") legend(off)   xtitle(" "   "No. of Elections")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(color(white)) note("N=415; Scenario: 1987 and later = 0, Contamination = 0")
  saving(learn00, replace)
xlab(1(1)10,  angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%" -0.1 "-10%",angle(0) nogrid) ytitle("");
#delimit cr

#delimit ;
twoway line slope00 learnlocal if learnlocal>0 & learnlocal<=5, sort 
|| line slope10 learnlocal if learnlocal>0 & learnlocal<=3, sort 
|| line slope01 learnlocal if learnlocal>0 & learnlocal<=10, sort 
|| line slope11 learnlocal if learnlocal>0 & learnlocal<=7, sort ,  
  title( "Strategic Desertion and Learning", span)
  subtitle(" ") legend(off)   xtitle(" "   "No. of Elections")  /*immer zwischen " und " steht eine Zeile vom xtitle*/
  graphregion(color(white))
  saving(learnl, replace)
xlab(1(1)10,  angle(0))
ylabel(0 "0%" -0.02 "-2%" -0.04 "-4%" -0.06 "-6%" -0.08 "-8%",angle(0)) ytitle("");
#delimit cr


#delimit ;
gr combine learn11.gph learn01.gph learn10.gph learn00.gph ,  
  title( "Strategic Desertion and Learning", span)
graphregion(color(white)) saving(learn, replace);
#delimit cr


graph export learne.tif, replace
drop  sterr slope*
log close
exit
